# ptcx
A format for modularized AST-based patching of arbitary code.

<p>
    <a href="https://pypi.org/project/ptcx/">
        <img alt="Pypi version" src="https://img.shields.io/pypi/v/ptcx?color=blue">
    </a>
    <a href="https://chrxer.github.io/ptcx/">
        <img alt="Pypi version" src="https://img.shields.io/badge/Docs-blue">
    </a>
</p>


Installation
```python
python3 -m pip install ptcx
```